#!/usr/bin/python
#
# Copyright 2013, Canonical
# Copyright 2013, Ben Howard <ben.howard@canonical.com>
#
# License: http://www.gnu.org/licenses/gpl.html GPL version 2 or higher
#
# This program setups the redirect port Juju.

from cloudinit import util as ciutil
from jujuclient import Environment
import socket
import sys
from time import sleep, time
import yaml

juju_cfg = None
with open('/home/vagrant/.juju/environments.yaml', 'r') as f:
    juju_cfg = yaml.load(f)

admin_secret = juju_cfg['environments']['local']['admin-secret']
# While this script is invoked when the Juju state server has been
# started, the server may not yet be ready to accept connections.
wait_until = time() + 30
while True:
    try:
        env = Environment("wss://localhost:17070")
        break
    except socket.error:
        if time() > wait_until:
            raise
        sleep(5)
env.login(admin_secret)
env.set_config('juju-gui', {'login-help': """
Welcome to the Juju Quick Start GUI!

This is a private instance of Juju GUI accessable only to your local
machine. NOTE: This Juju GUI installation is for demonstration,
development and other non-production uses.

\n\nYour Password is: %s""" % admin_secret})

watcher = env.watch()
env.wait_for_units()

public_address = None
for watch in watcher:
    for w in watch:
        if 'unit' not in w:
            continue

        _service = w[2]
        if 'Service' in _service and \
           'juju-gui' in _service['Service'] and \
           'PublicAddress' in _service:
            public_address = _service['PublicAddress']
            service_unit = _service
            break

    if service_unit:
        break

if len(sys.argv) > 1:
    redirect_port = int(sys.argv[1])
else:
    redirect_port = 8001
print """
Setting up transparent redirect for Juju-Gui
Redirecting localhost:%i to %s:80
""" % (redirect_port, public_address)

# Commands for IPTABLES
ip_cmds = [
    "sudo iptables -t nat -A PREROUTING -p tcp --dport %i -j DNAT --to %s:80" % \
        (redirect_port, public_address),
    "sudo iptables -t nat -A POSTROUTING -j MASQUERADE"
]

for cmd in ip_cmds:
    print "Executing: %s" % cmd
    ciutil.subp(cmd.split())

print """
From your browser on your hosts, you should be able to
access the GUI by going to: http://127.0.0.1:6080

Your password is: %s
""" % admin_secret
